pub trait SecureSpecCombinator: SpecCombinator { }Expand description
Theorems and lemmas that must be proven for a combinator to be considered correct and secure.
pub trait SecureSpecCombinator: SpecCombinator { }Theorems and lemmas that must be proven for a combinator to be considered correct and secure.